@@ -194,92 +194,78 @@ my $WMI_INFO = {
 };
 
 my %RENAME = qw(
-    DataWidth                   data_width
-    CurrentClockSpeed           speed
-    MaxClockSpeed               max_speed
-    ExtClock                    bus_speed
-    AddressWidth                address_width
-    Name                        name
-    LoadPercentage              load
-    DeviceID                    device_id
-    SocketDesignation           socket_designation
-    Status                      status_string
-    CpuStatus                   status
-    StatusInfo                  status_info
+    DataWidth           data_width
+    CurrentClockSpeed   speed
+    MaxClockSpeed       max_speed
+    ExtClock            bus_speed
+    AddressWidth        address_width
+    Name                name
+    LoadPercentage      load
+    DeviceID            id
+    SocketDesignation   socket_designation
+    Status              status_string
+    CpuStatus           status
+    StatusInfo          status_info
 
-    Description                 description
-    Manufacturer                manufacturer
-    Caption                     caption
-    Version                     version
-    Revision                    revision
-    Stepping                    stepping
-    Level                       level
-    Family                      family
+    Description         description
+    Manufacturer        manufacturer
+    Caption             caption
+    Version             version
+    Revision            revision
+    Stepping            stepping
+    Level               level
+    Family              family
 
-    Architecture                architecture
-    ProcessorType               processor_type
-    ProcessorId                 processor_id
-    CurrentVoltage              current_voltage
-    UpgradeMethod               upgrade_method
-    Availability                availability
+    L2CacheSize         cache2_size
 
-    NumberOfCores               number_of_cores
-    NumberOfLogicalProcessors   number_of_logical_processors
+    Architecture        architecture
+    ProcessorType       type
+    ProcessorId         pid
+    CurrentVoltage      voltage
+    UpgradeMethod       upgrade_method
+    Availability        availability
 );
 
-# TODO: Only available under Vista
-my @VISTA_OPTIONS = qw( L3CacheSpeed L3CacheSize );
+# TODO: Only available under Vista (which I don't have any access right now)
+my @VISTA_OPTIONS = qw(
+    NumberOfCores
+    NumberOfLogicalProcessors
+    L3CacheSpeed
+    L3CacheSize
+);
 
 my @__JUNK = qw(
-    ConfigManagerErrorCode
-    ConfigManagerUserConfig
-    ErrorCleared
-    ErrorDescription
-    InstallDate
-    L2CacheSpeed
-    LastErrorCode
-    OtherFamilyDescription
-    PNPDeviceID
-    PowerManagementCapabilities
-    PowerManagementSupported
-    UniqueId
-    VoltageCaps
+    ConfigManagerErrorCode        
+    ConfigManagerUserConfig        
+    ErrorCleared        
+    ErrorDescription        
+    InstallDate        
+    L2CacheSpeed        
+    LastErrorCode        
+    OtherFamilyDescription        
+    PNPDeviceID        
+    PowerManagementCapabilities       
+    PowerManagementSupported        
+    UniqueId        
+    VoltageCaps        
 );
 
 POPULATE_UNSUPPORTED: {
-    for my $j( @__JUNK ){
-        $RENAME{ $j } = '____' . $j;
+    for my $ij( @__JUNK ){
+        $RENAME{ $ij } = '____' . $ij;
     }
 }
 
-my %Win32_CacheMemory_names = qw(
-    DeviceID           device_id
-    Associativity      associativity
-    Availability       availability
-    BlockSize          block_size
-    CacheType          cache_type
-    Caption            caption
-    ErrorCorrectType   error_correct_type
-    InstalledSize      installed_size
-    Level              level
-    MaxCacheSize       max_cache_size
-    Name               name
-    NumberOfBlocks     number_of_blocks
-    Purpose            purpose
-    Status             status
-    StatusInfo         status_info
-);
+sub meaning {
+    my $self = shift;
+    my $name = shift || return;
+   
+}
 
-my %LCache_names = qw(
-    L1-Cache   L1_cache
-    L2-Cache   L2_cache
-    L3-Cache   L3_cache
-);
-
-sub _fetch_from_wmi {
+sub wmi_cpu {
     my $self     = shift;
     my $is_cache = $self->{cache};
-    my $ctimeout = $self->{cache_timeout} || 10; # in seconds
+    my $ctimeout = $self->{cache_timeout} || $self->DEFAULT_TIMEOUT; # in seconds
     if ($is_cache && $CACHE) {
         if ($CACHE->{TIMESTAMP} + $ctimeout < time) {
             %{ $CACHE } = ();
@@ -288,38 +274,23 @@ sub _fetch_from_wmi {
             return @{ $CACHE->{DATA} };
         }
     }
-
     local $SIG{__DIE__};
     local $@;
-
-    my %Lcache;
-    my @Win32_CacheMemory_names = keys %Win32_CacheMemory_names;
-    foreach my $f ( in WMI_FOR('Win32_CacheMemory') ) {
-        my $purpose = $f->Purpose;
-        next if $purpose !~ m{ \A L \d \- Cache }xmsi;
-        $Lcache{ $LCache_names{ $purpose } } = {
-            map {
-                $Win32_CacheMemory_names{$_},
-                $f->$_()
-            } @Win32_CacheMemory_names
-        };
-    }
-
-    my(%attr, @attr, $val, $info);
-    OUTER: foreach my $cpu (in WMI_FOR('Win32_Processor') ) {
-        INNER: foreach my $name (keys %RENAME) {
+    my(%attr, @attr, $val);
+    my $cache;
+    my @Lcache;
+    my $info;
+    foreach my $cpu (in WMI_FOR('Win32_Processor') ) {
+        foreach my $name (keys %RENAME) {
             eval { $val = $cpu->$name(); };
             if ( $@ ) {
                 warn "[WMI ERROR] $@\n";
-                next INNER;
-            }
-            next INNER if not defined $val;
-            if ( $name eq 'Name' ) {
-                $val =~ s{\s+}{ }xmsg;
-                $val =~ s{\A \s+}{}xms;
+                next;
             }
+            next if not defined $val;
+            $val =~ s{\A \s+}{}ms if $name eq 'Name';
             $attr{ $RENAME{$name} } = $val;
-            $info = $WMI_INFO->{ $name } || next INNER;
+            $info = $WMI_INFO->{ $name } || next;
             $attr{ $RENAME{$name} } = $info->{ $attr{ $RENAME{$name} } }
                                       ||
                                       $attr{ $RENAME{$name} };
@@ -327,14 +298,23 @@ sub _fetch_from_wmi {
         if($attr{bus_speed} && $attr{speed}) {
             $attr{multiplier} = sprintf '%.2f', $attr{speed} / $attr{bus_speed};
         }
-        $attr{current_voltage} /= 10 if $attr{current_voltage};
-        # LoadPercentage : returns undef
+        $attr{voltage} /= 10 if $attr{voltage};
+        if ( not $attr{cache2_size}) {
+            if (! @Lcache ) {
+                $cache ||= WMI_FOR('Win32_CacheMemory');
+                foreach my $c ( in $cache ) {
+                    push @Lcache, $c->MaxCacheSize;
+                }
+            }
+            $attr{cache1_size} = $Lcache[0];
+            $attr{cache2_size} = $Lcache[1];
+        }
+        # LoadPercentage : undef dnyor
         $attr{load} = sprintf('%.2f', $attr{load} / 100) if $attr{load};
-        push @attr, {%attr, %Lcache };
+        push @attr, {%attr};
         %attr = (); # reset
     }
-
-    $CACHE = { TIMESTAMP => time, DATA => [@attr] } if $is_cache;
+    $CACHE = { TIMESTAMP => time, DATA => [@attr] } if $is_cache; 
     return @attr;
 }
 
@@ -352,7 +332,7 @@ Nothing public here.
 
 =head1 DESCRIPTION
 
-WMI plugin.
+WMI plugin for C<Sys::Info::Driver::Windows::Device::CPU::WMI>.
 
 =head1 SEE ALSO
 
